@@ -31,6 +31,7 @@ from ..crud import (
     fetch_course,
     fetch_page_activity_counts,
     fetch_all_course_attributes,
+    fetch_subchapters,
 )
 from ..models import UseinfoValidation
 from ..session import auth_manager, is_instructor
@@ -134,11 +135,17 @@ async def serve_page(
     else:
         # The course requires a login but the user is not logged in
         if course_row.login_required and not user:
+            rslogger.debug(
+                f"Course not found: {course_name} not in database redirect to login"
+            )
             return RedirectResponse(url=f"{settings.login_url}")
 
         # The user is logged in, but their "current course" is not this one.
         # Send them to the courses page so they can properly switch courses.
         if user and user.course_name != course_name:
+            rslogger.debug(
+                f"Course mismatch: course name: {user.course_name} does not match requested course: {course_name} redirecting"
+            )
             return RedirectResponse(url=f"/runestone/default/courses")
 
     rslogger.debug(f"Base course = {course_row.base_course}")
@@ -192,6 +199,7 @@ async def serve_page(
             timestamp=datetime.utcnow(),
         )
     )
+    subchapter_list = await fetch_subchaptoc(course_row.base_course, chapter)
     context = dict(
         request=request,
         course_name=course_name,
@@ -205,6 +213,7 @@ async def serve_page(
         activity_info=json.dumps(activity_info),
         settings=settings,
         is_logged_in=logged_in,
+        subchapter_list=subchapter_list,
         serve_ad=serve_ad,
         is_instructor="true" if user_is_instructor else "false",
         readings=[],
@@ -255,3 +264,15 @@ def safe_join(directory, *pathnames):
             return None
         parts.append(filename)
     return posixpath.join(*parts)
+
+
+async def fetch_subchaptoc(course: str, chap: str):
+    res = await fetch_subchapters(course, chap)
+    toclist = []
+    for row in res:
+        rslogger.debug(f"row = {row}")
+        sc_url = "{}.html".format(row[0])
+        title = row[1]
+        toclist.append(dict(subchap_uri=sc_url, title=title))
+
+    return toclist
